# mummer

**DOI:** [10.5281/zenodo.10936493](https://doi.org/10.5281/zenodo.10936493)

## Available Versions
- **Version 3.23.0**
  - [Download](https://zenodo.org/record/10936494/files/mummer_3.23.0.img)
  - **MD5:** `33ffbc8c2697f856226ee894ee4b6153`
  - **DOI:** [10.5281/zenodo.10936494](https://doi.org/10.5281/zenodo.10936494)
  - **Size:** 145.54 MB
  - **Binaries:** 0 available

## Binaries (12 total)

```show-diff nucmer promer run-mummer1 dnadiff run-mummer3 mummer mummerplot repeat-match show-snps show-coords delta-filter```
